@@ -1,8 +1,10 @@
 package WWW::Mechanize::FormFiller::Value::Random;
+use strict;
 use base 'WWW::Mechanize::FormFiller::Value';
+use Data::Random qw(rand_enum);
 
 use vars qw( $VERSION );
-$VERSION = 0.03;
+$VERSION = '0.09';
 
 sub new {
   my ($class,$name,@values) = @_;
@@ -14,19 +16,18 @@ sub new {
 
 sub value {
   my ($self,$input) = @_;
-  my @values = $self->{values};
-  my $count = length @values;
+  my @values;
+  @values = @{$self->{values}}
+    if ($self->{values});
 
   # Pick a choice among the allowed values for this input
   # unless we got some prespecified values
-  @values = $input->possible_values unless $count;
-
-  $values[rand $count];
+  @values = $input->possible_values unless scalar @values;
+  rand_enum( set => \@values, size => 1 );
 };
 
 1;
 
-
 __END__
 
 =head1 NAME
@@ -35,7 +36,7 @@ WWW::Mechanize::FormFiller::Value::Random - Randomly fill out a HTML form field
 
 =head1 SYNOPSIS
 
-=begin example
+=for example begin
 
   use WWW::Mechanize::FormFiller;
   use WWW::Mechanize::FormFiller::Value::Random;
@@ -53,7 +54,17 @@ WWW::Mechanize::FormFiller::Value::Random - Randomly fill out a HTML form field
   # If there is no password, put a random one out of the list there
   my $password = $f->add_filler( password => Random => "foo","bar","baz" );
 
-=end example
+=for example end
+
+=for example_testing
+  require HTML::Form;
+  my $form = HTML::Form->parse('<html><body><form method=get action=/>
+  <input type=text name=login />
+  <input type=text name=password />
+  </form></body></html>','http://www.example.com/');
+  $f->fill_form($form);
+  like( $form->value('login'), qr/^(root|administrator|corion)$/, "Login gets set");
+  like( $form->value('password'), qr/^(foo|bar|baz)$/, "Password gets set");
 
 =head1 DESCRIPTION
 
